struct DrawProps {
positioning_transform: Affine,
effective_transform: Affine,
font_size: f32,
}Expand description
Properties for easily calculating the transform of a positioned glyph.
Fields
positioning_transform: AffineA positioning transform for the glyph.
effective_transform: AffineA transform to apply to the glyph after positioning.
font_size: f32The actual font size that should be assumed for drawing and caching purposes.
Implementations