pub(crate) struct GlyphOutline {
pub(crate) path: Arc<BezPath>,
pub(crate) bbox: Rect,
pub(crate) scale: f64,
}Expand description
A glyph defined by a path (its outline) and a local transform.
Fields
path: Arc<BezPath>The path of the glyph (shared with the outline cache via Arc).
bbox: RectPrecise bounding box of the path at the cached outline size.
scale: f64Scale from the cached outline size to the requested draw size.