GlyphRunBuilder

Struct GlyphRunBuilder 

pub struct GlyphRunBuilder<'a, B> {
    run: GlyphRun<'a>,
    backend: B,
}
A builder for configuring and drawing glyphs.

Fields

run: GlyphRun<'a>backend: B

Implementations

Source

impl<'a, B> GlyphRunBuilder<'a, B>

pub fn new( font: FontData, transform: Affine, paint_transform: Affine, backend: B, ) -> Self

Creates a new builder for drawing glyphs with a pre-bound backend.

pub fn font_size(self, size: f32) -> Self

Set the font size in pixels per em.

pub fn font_embolden(self, embolden: FontEmbolden) -> Self

Set synthetic embolden settings.

pub fn glyph_transform(self, transform: Affine) -> Self

Set the per-glyph transform. Use Affine::skew with a horizontal-only skew to simulate italic text.

pub fn hint(self, hint: bool) -> Self

Set whether font hinting is enabled.

This performs vertical hinting only. Hinting is performed only if the combined transform and glyph_transform have a uniform scale and no vertical skew or rotation.

pub fn normalized_coords(self, coords: &'a [NormalizedCoord]) -> Self

Set normalized variation coordinates for variable fonts.

Source

impl<'a, B> GlyphRunBuilder<'a, B>
where B: GlyphRunBackend<'a>,

pub fn atlas_cache(self, enabled: bool) -> Self

Enable or disable the glyph atlas cache.

Note: Atlas caching is currently highly experimental and not recommended for external use.

pub fn fill_glyphs<Glyphs>(self, glyphs: Glyphs)
where Glyphs: Iterator<Item = Glyph> + Clone,

Fill the glyphs using the current settings.

pub fn stroke_glyphs<Glyphs>(self, glyphs: Glyphs)
where Glyphs: Iterator<Item = Glyph> + Clone,

Stroke the glyphs using the current settings.

pub fn render_decoration<Glyphs>( self, glyphs: Glyphs, x_range: RangeInclusive<f32>, baseline_y: f32, offset: f32, size: f32, buffer: f32, )
where Glyphs: Iterator<Item = Glyph> + Clone,

Render a decoration (e.g. underline) with skip-ink behavior.

See GlyphRunRenderer::render_decoration.