PreparedGlyph

Struct PreparedGlyph 

pub(crate) struct PreparedGlyph<'a> {
    pub(crate) glyph_type: GlyphType<'a>,
    pub(crate) outline_transform: Affine,
    pub(crate) relative_paint_transform: Affine,
    pub(crate) cache_key: Option<GlyphCacheKey>,
}
A simplified representation of a glyph, prepared for easy rendering.

Fields

glyph_type: GlyphType<'a>

The type of glyph.

outline_transform: Affine

Per-glyph outline transform: maps the draw-unit glyph outline (after font-size absorption) to scene coordinates.

relative_paint_transform: Affine

The transform of the paint, relative to PreparedGlyph::outline_transform * GlyphScaleProperties::draw_scale.

cache_key: Option<GlyphCacheKey>

Cache key for renderers that implement glyph caching. This is Some for glyphs that can be cached, None otherwise.

For COLR glyphs, context_color is extracted from the renderer’s current paint during cache key creation.