pub struct GlyphColr<'a> {
pub skrifa_glyph: ColorGlyph<'a>,
pub location: LocationRef<'a>,
pub font_ref: &'a FontRef<'a>,
pub(crate) font_info: FontInfo,
pub draw_transform: Affine,
pub area: Rect,
pub pix_width: u16,
pub pix_height: u16,
pub has_non_default_blend: bool,
}Expand description
A glyph defined by a COLR glyph description.
Clients are supposed to first draw the glyph into an intermediate image texture/pixmap and then render that into the actual scene, in a similar fashion to bitmap glyphs.
Fields
skrifa_glyph: ColorGlyph<'a>The original skrifa color glyph.
location: LocationRef<'a>The location of the glyph.
font_ref: &'a FontRef<'a>The font reference.
font_info: FontInfoBasic metadata about the font.
draw_transform: AffineThe transform to apply to the glyph.
area: RectThe rectangular area that should be filled with the rendered representation of the COLR glyph when painting.
pix_width: u16The width of the pixmap/texture in pixels to which the glyph should be rendered to.
pix_height: u16The height of the pixmap/texture in pixels to which the glyph should be rendered to.
has_non_default_blend: boolWhether the glyph paint graph uses a non-default blend mode.